@@ -1,32 +1,17 @@
 /*
-    Copyright 2016 David Rosca <nowrep@gmail.com>
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "server.h"
 #include "context.h"
+#include "debug.h"
 #include "sink.h"
 #include "source.h"
-#include "debug.h"
 
 namespace QPulseAudio
 {
-
 Server::Server(Context *context)
     : QObject(context)
     , m_defaultSink(nullptr)
@@ -79,11 +64,12 @@ void Server::update(const pa_server_info *info)
 {
     m_defaultSinkName = QString::fromUtf8(info->default_sink_name);
     m_defaultSourceName = QString::fromUtf8(info->default_source_name);
+    m_isPipeWire = QString::fromUtf8(info->server_name).contains("PipeWire");
 
     updateDefaultDevices();
 }
 
-template <typename Type, typename Map>
+template<typename Type, typename Map>
 static Type *findByName(const Map &map, const QString &name)
 {
     Type *out = nullptr;
@@ -120,4 +106,9 @@ void Server::updateDefaultDevices()
     }
 }
 
+bool Server::isPipeWire() const
+{
+    return m_isPipeWire;
+}
+
 } // QPulseAudio
