@@ -1,21 +1,7 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef VOLUMEOBJECT_H
@@ -27,7 +13,6 @@
 
 namespace QPulseAudio
 {
-
 class VolumeObject : public PulseObject
 {
     Q_OBJECT
@@ -42,7 +27,7 @@ public:
     explicit VolumeObject(QObject *parent);
     ~VolumeObject() override;
 
-    template <typename PAInfo>
+    template<typename PAInfo>
     void updateVolumeObject(PAInfo *info)
     {
         updatePulseObject(info);
@@ -92,8 +77,14 @@ public:
     virtual void setChannelVolumes(const QVector<qint64> &channelVolumes) = 0;
     Q_INVOKABLE virtual void setChannelVolume(int channel, qint64 volume) = 0;
 
-    virtual quint32 sourceIndex() const {return -1;};
-    virtual quint32 streamIndex() const {return -1;};
+    virtual quint32 sourceIndex() const
+    {
+        return -1;
+    };
+    virtual quint32 streamIndex() const
+    {
+        return -1;
+    };
 
 Q_SIGNALS:
     void volumeChanged();
